"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.remove = void 0;

var _path = _interopRequireDefault(require("path"));

var _fs = _interopRequireDefault(require("fs"));

var _matcher = _interopRequireDefault(require("matcher"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

let rootPath = null;
let ignoreFiles = null;
let explicitlyDelFiles = null;

const isSameFile = target => f => {
  const currFilePath = _path.default.resolve(rootPath, f);

  return _matcher.default.isMatch(target, currFilePath);
};

const notNeedRemove = dir => {
  if (!rootPath) return true;
  if (rootPath === dir) return false;

  if (!!explicitlyDelFiles) {
    const inExplicitlyDelFiles = explicitlyDelFiles.some(isSameFile(dir));
    return !inExplicitlyDelFiles;
  }

  const inIgnoreFiles = ignoreFiles.some(isSameFile(dir));
  return inIgnoreFiles;
};

const initModuleVars = (dir, _ignoreFiles, _explicitlyDelFiles) => {
  if (!rootPath) rootPath = dir;
  if (!ignoreFiles && _ignoreFiles) ignoreFiles = _ignoreFiles;
  if (!explicitlyDelFiles && _explicitlyDelFiles) explicitlyDelFiles = _explicitlyDelFiles;
};

const rmdirSync = dir => {
  const fileinfo = _fs.default.statSync(dir);

  if (fileinfo.isFile()) {
    _fs.default.unlinkSync(dir);
  } else if (fileinfo.isDirectory()) {
    const files = _fs.default.readdirSync(dir);

    for (let i = 0; i < files.length; i++) rmdirSync(_path.default.join(dir, files[i]));
  }
};

const remove = (outputPath, _ignoreFiles, _explicitlyDelFiles) => {
  initModuleVars(outputPath, _ignoreFiles, _explicitlyDelFiles);

  if (_fs.default.existsSync(outputPath)) {
    for (let item of _fs.default.readdirSync(outputPath)) {
      const itemPath = _path.default.resolve(outputPath, item);

      if (!notNeedRemove(itemPath)) {
        rmdirSync(itemPath);
      }
    }
  }
};

exports.remove = remove;
//# sourceMappingURL=utils.js.map